+++++++++++++
Install Hachoir
+++++++++++++++

To install Hachoir, type::

    python3 -m pip install -U hachoir

For use hachoir-urwid, you will also need to install `urwid library
<http://excess.org/urwid/>`_::

    python3 -m pip install -U urwid

Hachoir requires Python 3.3 or newer.
